* rawdataNJ_t1.do

capture log close
log using rawdataNJ_t1.txt, text replace
clear
set more off 
set varabbrev off
global data /data/home/sh2989/nj_vital_statistics/data/

foreach y in 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 {
quietly append using ${data}/nj`y'merged.dta
capture drop censusblocknumber
}

foreach v in agelt20 age2024 age2529 age3034 age35p agemissing {
	gen `v' = 0
}
replace agelt20 = 1 if momage > 0 & momage < 20
replace age2024 = 1 if momage >= 20 & momage <=24
replace age2529 = 1 if momage >= 25 & momage <=29
replace age3034 = 1 if momage >= 30 & momage <=34
replace age35p  = 1 if momage >=35 & !missing(momage)
replace agemissing = 1 if missing(momage) | momage == 0

foreach v in black white hispanic raceother racemissing {
	gen `v' = 0
}
replace black     = 1 if orracem == 7
replace white     = 1 if orracem == 6
replace hispanic  = 1 if orracem == 1 | orracem == 2 | orracem == 3 | orracem == 4 | orracem == 5 
replace raceother = 1 if orracem == 8
replace racemissing = 1 if missing(orracem)

foreach v in edulths eduhs edusomecollege edumtcollege edumissing {
	gen `v' = 0
}
replace edulths = 1 if momedu_categories == 1
replace eduhs   = 1 if momedu_categories == 2
replace edusomecollege = 1 if momedu_categories == 3
replace edumtcollege   = 1 if momedu_categories == 4
replace edumissing     = 1 if missing(momedu_categories)

gen marriedmissing = 0
replace marriedmissing = 1 if missing(married)
replace married = 0 if missing(married)
label drop married

gen medicaid_missing = 0
replace medicaid_missing = 1 if missing(medicaid)
replace medicaid = 0 if missing(medicaid)

gen multibir_missing = 0
replace multibir_missing = 1 if missing(multibir)
replace multibir = 0 if missing(multibir)

foreach v in parity1 parity2 parity3 parity4p paritymissing {
	gen `v' = 0
}

replace parity = 1 if missing(parity) & nowlive == 0
replace parity1  = 1 if parity == 1
replace parity2  = 1 if parity == 2
replace parity3  = 1 if parity == 3
replace parity4p = 1 if parity >= 4 & !missing(parity)
replace paritymissing = 1 if missing(parity) 

gen csection = 0 
replace csection = 1 if deliv_method == 2 | deliv_method == 6

gen prevcsection = 0
replace prevcsection = 1 if deliv_method == 5 | deliv_method == 6

gen breech = 0
replace breech = 1 if cl_breech == 1
gen breechmissing = 0
replace breechmissing = 1 if missing(cl_breech)

gen cephalopelvic = 0
replace cephalopelvic = 1 if cl_cephalopelvic == 1
gen cephalopelvicmissing = 0
replace cephalopelvicmissing = 1 if missing(cl_cephalopelvic)

gen placentaprevia = 0
replace placentaprevia = 1 if cl_previa == 1
gen placentapreviamissing = 0
replace placentapreviamissing = 1 if missing(cl_previa)

foreach v in anemia cardiac ch_hypertension diabetes eclampsia hemoglob herpes hydramnios inc_cervix lung {
	gen `v' = 0
	replace `v' = 1 if mr_`v' == 1
	gen `v'missing = 0
	replace `v'missing = 1 if missing(mr_`v')
}
	
foreach v in oth_mom_risk oth_std pr_hypertension prev_large prev_preterm renal_disease rh_sens uterine_bleeding {
	gen `v' = 0
	replace `v' = 1 if mr_`v' == 1
	gen `v'missing = 0
	replace `v'missing = 1 if missing(mr_`v')
}
	
foreach v in abruptio cord_prolapse {
	gen `v' = 0
	replace `v' = 1 if cl_`v' == 1
	gen `v'missing = 0
	replace `v'missing = 1 if missing(cl_`v')
}
	
gen riskfactors = 0
replace riskfactors = 1 if highrisk == 1
gen riskfactorsmissing = 0
replace riskfactorsmissing = 1 if missing(highrisk)

local age                     agelt20 age2529 age3034 age35p agemissing
local parity                  parity2 parity3 parity4p paritymissing
local breech                  breech breechmissing
local cephalopelvic           cephalopelvic cephalopelvicmissing
local medriskfactors1         anemia cardiac ch_hypertension diabetes eclampsia hemoglob herpes hydramnios inc_cervix lung
local medriskfactors2         oth_mom_risk oth_std pr_hypertension prev_large prev_preterm renal_disease rh_sens uterine_bleeding
local complications           abruptio placentaprevia cord_prolapse
local medriskfactors1missing  anemiamissing cardiacmissing ch_hypertensionmissing diabetesmissing eclampsiamissing hemoglobmissing herpesmissing hydramniosmissing inc_cervixmissing lungmissing
local medriskfactors2missing  oth_mom_riskmissing oth_stdmissing pr_hypertensionmissing prev_largemissing prev_pretermmissing renal_diseasemissing rh_sensmissing uterine_bleedingmissing
local complicationsmissing    abruptiomissing placentapreviamissing cord_prolapsemissing

logit   csection `age' prevcsection `parity' multibir `breech' `cephalopelvic' `medriskfactors1' `medriskfactors2' `complications' `medriskfactors1missing' `medriskfactors2missing' `complicationsmissing' 

log close








